@@ -77,9 +77,21 @@ def init_app(app):
     if os.path.isfile(config_file):
         config_settings.read(config_file)
     else:
-        print("  Config File could not be loaded, created a new one with default values...")
+        print("\033[1;36;40m  Config File could not be loaded, created a new one with default values...\033[1;37;40m")
         create_config(config_file)
 
+    # Get Version
+    try:
+        version_file = Config.version_file
+        with open(version_file, 'r') as file:
+            version = file.read().replace('\n', '')
+    except Exception:
+        version = 'unknown'
+    with app.app_context():
+        app.version = version
+
+    print(f"\033[1;37;40m  Running version: {version}\033[1;37;40m")
+
     with app.app_context():
         app.settings = config_settings
     with app.app_context():
@@ -110,23 +122,23 @@ def init_app(app):
     # 2. Specter python library found?
 
     # Check Specter
-    print("  Checking Specter Server status ...")
+    print("\033[1;37;40m  Checking Specter Server status ...")
     specter_checks()
-    print("  Loading Specter data ...")
+    print("\033[1;37;40m  Loading Specter data ...")
     app.specter = load_specter()
 
     from warden.warden_pricing_engine import test_tor
-    print("  Testing Tor ...")
+    print("\033[1;37;40m  Testing Tor ...")
     app.tor = test_tor()
     if app.tor:
-        print("✓ Tor Running")
+        print("\033[1;32;40m✓ Tor Running\033[1;37;40m")
     else:
-        print("  Tor disabled - check your connection or Tor browser")
+        print("\033[1;33;40m  Tor disabled - check your connection or Tor browser")
 
-    print("  Checking Services Status ...")
+    print("\033[1;37;40m  Checking Services Status ...")
     app.services = check_services()
 
-    print("✓ Application startup is complete")
+    print("\033[1;32;40m✓ Application startup is complete\033[1;37;40m")
 
     return app
 
@@ -140,12 +152,6 @@ def create_and_init():
 
 def main():
     # CLS + Welcome
-    # Get version
-    try:
-        with open('version.txt', 'r') as file:
-            version = file.read().replace('\n', '')
-    except Exception:
-        version = 'unknown'
 
     print("\033[1;32;40m")
     for _ in range(50):
@@ -159,7 +165,6 @@ def main():
         | |_| | | |  __/   \ V  V / ___ \|  _ < (_| |  __/ | | |
          \__|_| |_|\___|    \_/\_/_/   \_\_| \_\__,_|\___|_| |_|
                                         Specter Server Edition
-                                        version {version}
     -----------------------------------------------------------------
     \033[1;37;40m       Privacy Focused Portfolio & Bitcoin Address Tracker
     \033[1;32;40m-----------------------------------------------------------------
@@ -173,6 +178,7 @@ def main():
     \033[1;32;40m-----------------------------------------------------------------
     \033[1;37;40m                     CTRL + C to quit server
     \033[1;32;40m-----------------------------------------------------------------
+    \033[1;37;40m
     """)
 
     print("  Launching Application ...")
@@ -207,7 +213,7 @@ def main():
     atexit.register(close_running_threads)
 
     print("  Launching Server ...")
-    print("✓ WARden Server is Ready")
+    print("\033[1;32;40m✓ WARden Server is Ready\033[1;37;40m")
     app.run(debug=app.settings['SERVER']['debug'],
             threaded=True,
             host='0.0.0.0',
